@@ -7,8 +7,8 @@ from targets.values import register_value_type
 
 @dbnd.hookimpl
 def dbnd_setup_plugin():
-    from tensorflow.keras.callbacks import History
     from tensorflow.keras import models
+    from tensorflow.keras.callbacks import History
 
     from dbnd_tensorflow.marshalling.tensorflow_marshaller import (
         TensorflowKerasHistoryMarshaller,
@@ -20,10 +20,10 @@ def dbnd_setup_plugin():
     )
 
     register_marshaller(
-        models.Model, FileFormat.tfmodel, TensorflowKerasModelMarshaller(),
+        models.Model, FileFormat.tfmodel, TensorflowKerasModelMarshaller()
     )
     register_marshaller(
-        History, FileFormat.tfhistory, TensorflowKerasHistoryMarshaller(),
+        History, FileFormat.tfhistory, TensorflowKerasHistoryMarshaller()
     )
 
     register_value_type(TensorflowModelValueType())
